aboutsummaryrefslogtreecommitdiffstats
path: root/epan/column.h
diff options
context:
space:
mode:
authorMichal Labedzki <michal.labedzki@tieto.com>2015-12-11 09:34:08 +0100
committerAnders Broman <a.broman58@gmail.com>2015-12-20 08:21:02 +0000
commit9bb3f6be4c18822267a64633c298e1a8f1809221 (patch)
treede9b8934c58f239e29d0227039ad7f55f3d42f06 /epan/column.h
parent7e0ec2c8eb3c88e70992dc40b130c76177b83a30 (diff)
Qt: Add missing multi-field column validation
GTK already has it, but Qt forgot about it, so multi-field custom column works ok if previously saved in GTK-shark. Invalid validation prevent from modifying and saving multi-field custom column in Qt version. While at it, rename "custom field" to "custom fields" to ensure we think about multi-field custom column. Change-Id: I99588150ccb38be11b75f5dd5b0f6443e7055ebb Reviewed-on: https://code.wireshark.org/review/12685 Petri-Dish: Michal Labedzki <michal.labedzki@tieto.com> Tested-by: Petri Dish Buildbot <buildbot-no-reply@wireshark.org> Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan/column.h')
-rw-r--r--epan/column.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/column.h b/epan/column.h
index af19b07ca2..365652e2e4 100644
--- a/epan/column.h
+++ b/epan/column.h
@@ -33,7 +33,7 @@ extern "C" {
typedef struct _fmt_data {
gchar *title; /* title of the column */
int fmt; /* format of column */
- gchar *custom_field; /* field name for COL_CUSTOM */
+ gchar *custom_fields; /* fields names for COL_CUSTOM */
gint custom_occurrence; /* optional ordinal of occurrence of that field */
gboolean visible; /* if FALSE, hide this column */
gboolean resolved; /* if TRUE, show a more human-readable name */
@@ -64,9 +64,9 @@ gboolean get_column_resolved(const gint);
WS_DLL_PUBLIC
void set_column_resolved(const gint, gboolean);
WS_DLL_PUBLIC
-const gchar *get_column_custom_field(const gint);
+const gchar *get_column_custom_fields(const gint);
WS_DLL_PUBLIC
-void set_column_custom_field(const gint, const char *);
+void set_column_custom_fields(const gint, const char *);
WS_DLL_PUBLIC
gint get_column_custom_occurrence(const gint);
WS_DLL_PUBLIC